#
# spec file for package hg-git
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           hg-git
Version:        0.8.11
Release:        bp153.1.17
Summary:        Mercurial Plugin for Communicating with Git Servers
License:        GPL-2.0-or-later
Group:          Development/Tools/Version Control
URL:            https://hg-git.github.io
Source0:        https://files.pythonhosted.org/packages/d5/6b/e2eaef3ab80fc6dc5c97a669a182d127096d856e918841598cb03d264c2d/%{name}-%{version}.tar.gz
Source1:        https://files.pythonhosted.org/packages/d5/6b/e2eaef3ab80fc6dc5c97a669a182d127096d856e918841598cb03d264c2d/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
BuildRequires:  git-daemon
BuildRequires:  mercurial
BuildRequires:  netcat-openbsd
BuildRequires:  python-devel
BuildRequires:  python-dulwich >= 0.9.7
BuildRequires:  python-setuptools
Requires:       mercurial
Requires:       python-dulwich >= 0.9.7
Conflicts:      mercurial >= 4.6
BuildArch:      noarch

%description
This is the Hg-Git plugin for Mercurial, adding the ability to push and pull
to/from a Git server repository from Hg. This means you can collaborate on Git
based projects from Hg, or use a Git server as a collaboration point for a team
with developers using both Git and Hg.

The Hg-Git plugin can convert commits/changesets losslessly from one system to
another, so you can push via an Hg repository and another Hg client can pull it
and their changeset node ids will be identical - Mercurial data does not get
lost in translation.

%prep
%setup -q

%build
python setup.py build

%check
export PYTHONPATH="%{buildroot}%{python_sitelib}"
#pushd tests
#python run-tests.py --verbose --with-hg=%%{_bindir}/hg
#popd

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%license COPYING
%doc README.md
%{python_sitelib}

%changelog
* Tue Jun 19 2018 astieger@suse.com
- update to 0.8.11 (boo#1096561)
  * add config knob for marking git branches public
  * re-enable git subrepositories disabled in 4.4.1
  * fix compatibility with hg < 4.2
  * improve compatibility with hg 4.5+
- as this package is known not to work with mercurial 4.6, add
  a conflict
* Sun Nov 12 2017 astieger@suse.com
- update to 0.8.10:
  * mercurial 4.4 compatibility
  * drop hg-git.patch and disable test, this is in flux upstream
* Sat Aug 26 2017 olaf@aepfle.de
- update to v0.8.9
  no changelog provided by upstream
- remove weird tests with hg-git.patch
* Tue May  2 2017 mpluskal@suse.com
- Fix download url
* Mon May  1 2017 develop7@develop7.info
- update to v0.8.6
  * Support Mercurial 4.2-rc
  * Bugfixes
- enable tests back
- source verification added
* Mon Aug 15 2016 astieger@suse.com
- disable failing tests
* Tue Feb  2 2016 develop7@develop7.info
- update to v0.8.5
  * Support Mercurial 3.7
  * No changelog provided, see
    https://bitbucket.org/durin42/hg-git/branches/compare/0.8.5%%0D0.8.4
* Mon Feb  1 2016 mpluskal@suse.com
- Update project url
- Cleanups spec file with spec-cleaner
- Enable tests
* Mon Feb  1 2016 develop7@develop7.info
- update to v0.8.4
  * No changelog provided, see
    https://bitbucket.org/durin42/hg-git/branches/compare/0.8.4%%0D0.8.3
* Mon Dec  7 2015 develop7@develop7.info
- update to v0.8.3
  * fixes Mercurial 3.6 compatibility issues
  * Other changes: see https://bitbucket.org/durin42/hg-git/branches/compare/0.8.3%%0D0.8.2
- use %%version macro
- remove unused %%rev define
* Sat Oct  3 2015 Mathias.Homann@opensuse.org
- update to 0.8.2
  Changes: see upstream
* Sun Feb 22 2015 develop7@develop7.info
- require python-dulwich >= 0.9.7, as required by upstream setup.py
* Thu Feb  5 2015 gber@opensuse.org
- update to version 0.8.0
  - no changelog provided, see
    https://bitbucket.org/durin42/hg-git/commits/tag/0.8.0 for a
    detailed list of changes
* Sun Jan 18 2015 p.drouand@gmail.com
- Update to version 0.7.0
  * no changelog provided, see
    https://bitbucket.org/durin42/hg-git/commits/tag/0.7.0 for a
    detailed list of changes
- Remove unzip build requirement; not needed
- Cleanup specfile
- Remove depreciated -f INSTALLED_FILES and --record-rpm=INSTALLED_FILES
  and use {python_sitelib} instead
- Remove "env CFLAGS="$RPM_OPT_FLAGS""; useless for a noarch package
* Mon Aug 18 2014 gber@opensuse.org
- update to version 0.6.1
  - no changelog provided, see
    https://bitbucket.org/durin42/hg-git/commits/tag/0.6.1 for a
    detailed list of changes
* Mon May 26 2014 gber@opensuse.org
- update to version 0.6.0
  - no changelog provided, see
    https://bitbucket.org/durin42/hg-git/commits/tag/0.6.0 for a
    detailed list of changes
* Tue Dec 17 2013 gber@opensuse.org
- update to version 0.5.0
  - test-subrepos.t: hide output from newer hg versions about
    active bookmarks
  - testedwith: drop 2.3.1, which has at least one test failure
  - testedwith: add 2.8.1
  - gitignore: gate feature on dirstate having rootcache and ignore
    having readpats
  - git_handler: iterate over new refs in sorted order to stabilize
    test output
  - overlay: add kludge to make sure we only ever give hexshas to
    dulwich
  - test-timezone.t: add missing (but needed) trailing whitespace
  - tests: dulwich is now smarter about sending fewer objects,
    update output
  - setup: bump dep on dulwich to 0.9.4
  - git-handler: turn refs from None to {} so that empty git repos
    can convert
* Tue Dec  3 2013 gber@opensuse.org
- bump version to 0.4.0_hg20131127
* Mon Dec  2 2013 ohering@suse.de
- Update to 503d403fc040 to fix interface to python-dulwich 0.9.1
  - Export Git objects from incremental Mercurial changes
  - overlaymanifest: add iteritems(), used by recent hg versions
  - Only export modified Git trees
  - Fixes #54 | option branch_bookmark_suffix doesn't move bookmarks
  - Make the path part of URL contain a leading slash only if it's not
  - git_handler: skip exporting hg tags whose names are not valid as git
  - test-tree-decomposition: work around git command format changes
  - Update test output to handle 65d8a43b adding some more objects.
  - test-subrepos: cope with unsorted output in .hgsub
  - Upgraded to use latest version of dulwich (0.9.1).
  - Updated `setup.py` file to reflect requirement on newer version of
  - git_handler: clean up trailing whitespace
  - git_handler: fix bugs introduced by 47df57f2bb2b which could never
  - overlays: fix incoming support for hg 2.8
  - Fix for #68 | Use .gitignore files (with proper semantics)
* Tue Mar 26 2013 gber@opensuse.org
- update to version 0.4.0
  - Add test to show dulwich fault on invalid timezone data
  - scrub bad timezone values before dulwich sees them
  - push: provide better output about changed references
  - push: add more output about what was added
  - git_handler: add bookmark compatibility with new bmstore
  - git_handler: defend against unexported revisions in tag
    exporting
  - tests: use fn_git_commit in test-encoding.t
  - tests: make test-encoding.t compatible with git 1.8.0
  - tests: remove filterhash from test-incoming.t
  - tests: remove mercurial version check from test-incoming.t
  - tests: remove mercurial version check from
    test-pull-after-strip.t
  - tests: convert echos to comments
  - tests: avoid changing the current directory
  - tests: extract git command-line client and dulwich requirements
    into testutil
  - tests: let git init create directories when applicable
  - tests: add check for dulwich in test-url-parsing.py
  - tests: extract commonly used commit/tag functions into testutil
    library
  - tests: extract extension configuration into a testutil library
* Mon Jan  7 2013 tzotsos@opensuse.org
- update to version 0.3.4
  - remove git-daemon check from test-subrepos.t
  - test-pull.t: normalize git-merge output
  - overlaychangectx: fix compatibility with mercurial 2.4-rc (no attribute _repo)
  - pull: don't pull tags as bookmarks
  - push: fix traceback when pushing empty hg repo to empty git repo
  - push: change "no changes" default output to match normal mercurial
  - Verify tree and parent objects are in Git repo
  - outgoing: re-introduce support for outgoing
  - dulwich: require 0.8.6 or greater
  - makefile: add update support from hg 2.3 to hg 2.3.1
  - add fromgit and gitnode selectors
  - make test-encoding.t compatible with git 1.8.0
* Wed May 16 2012 gber@opensuse.org
- update to version 0.3.2
  - add support for the HTTP smart protocol when using Dulwich tip
  - updated documentation
  - support for newer dulwich and hg versions
  - allow generating a git repo that has the same "branch names" as
    an older hg repo that has named branches, and has had bookmarks
    added in to mirror the branch names
* Tue Oct 11 2011 gber@opensuse.org
- update to version 0.3.1
  - detailed list of changes available from
    https://bitbucket.org/durin42/hg-git/changesets/tip/tag%%28%%220.2.5%%22%%29..tag%%28%%220.3.1%%22%%29
- specfile cleanup
* Sat Dec 11 2010 nix@opensuse.org
- Update to version 0.2.5
- Change to noarch
- Change group to Development/Tools/Version Control
* Wed Sep  8 2010 nix@opensuse.org
- Initial stable package
